]> Dogcows Code - chaz/tar/blobdiff - src/tar.h
Update copyright years.
[chaz/tar] / src / tar.h
index a759a8581a0536f3c3e78466a43630a980179417..cb7d70cf62534c268b5e1b04f85d985ae6e78f31 100644 (file)
--- a/src/tar.h
+++ b/src/tar.h
@@ -1,21 +1,22 @@
 /* GNU tar Archive Format description.
 
-   Copyright (C) 1988, 1989, 1991, 1992, 1993, 1994, 1995, 1996, 1997,
-   2000, 2001, 2003, 2004, 2005 Free Software Foundation, Inc.
+   Copyright 1988-1989, 1991-1997, 2000-2001, 2003-2007, 2012-2014 Free
+   Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify it
-   under the terms of the GNU General Public License as published by the
-   Free Software Foundation; either version 2, or (at your option) any later
-   version.
+   This file is part of GNU tar.
 
-   This program is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
-   Public License for more details.
+   GNU tar is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
-   You should have received a copy of the GNU General Public License along
-   with this program; if not, write to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   GNU tar is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* tar Header Block, from POSIX 1003.1-1990.  */
 
@@ -80,9 +81,9 @@ struct posix_header
 /* tar Header Block, GNU extensions.  */
 
 /* In GNU tar, SYMTYPE is for to symbolic links, and CONTTYPE is for
-   contiguous files, so maybe disobeying the `reserved' comment in POSIX
+   contiguous files, so maybe disobeying the "reserved" comment in POSIX
    header description.  I suspect these were meant to be used this way, and
-   should not have really been `reserved' in the published standards.  */
+   should not have really been "reserved" in the published standards.  */
 
 /* *BEWARE* *BEWARE* *BEWARE* that the following information is still
    boiling, and may change.  Even if the OLDGNU format description should be
@@ -165,6 +166,7 @@ struct oldgnu_header
    'A' Solaris Access Control List
    'E' Solaris Extended Attribute File
    'I' Inode only, as in 'star'
+   'N' Obsolete GNU tar, for file names that do not fit into the main header.
    'X' POSIX 1003.1-2001 eXtended (VU version)  */
 
 /* This is a dir entry that contains the names of files that were in the
@@ -180,9 +182,6 @@ struct oldgnu_header
 /* This is the continuation of a file that began on another volume.  */
 #define GNUTYPE_MULTIVOL 'M'
 
-/* For storing filenames that do not fit into the main header.  */
-#define GNUTYPE_NAMES 'N'
-
 /* This is for sparse files.  */
 #define GNUTYPE_SPARSE 'S'
 
@@ -192,8 +191,7 @@ struct oldgnu_header
 /* Solaris extended header */
 #define SOLARIS_XHDTYPE 'X'
 
-\f
-/* Jörg Schilling star header */
+/* J@"org Schilling star header */
 
 struct star_header
 {                              /* byte offset */
@@ -221,7 +219,8 @@ struct star_header
 #define SPARSES_IN_STAR_HEADER      4
 #define SPARSES_IN_STAR_EXT_HEADER  21
 
-struct star_in_header {
+struct star_in_header
+{
   char fill[345];       /*   0  Everything that is before t_prefix */
   char prefix[1];       /* 345  t_name prefix */
   char fill2;           /* 346  */
@@ -236,11 +235,13 @@ struct star_in_header {
   char xmagic[4];       /* 508  "tar" */
 };
 
-struct star_ext_header {
+struct star_ext_header
+{
   struct sparse sp[SPARSES_IN_STAR_EXT_HEADER];
   char isextended;
 };
 
+/* END */
 \f
 
 /* tar Header Block, overall structure.  */
@@ -263,9 +264,25 @@ enum archive_format
 
 /* Information about a sparse file.  */
 struct sp_array
+{
+  off_t offset;
+  off_t numbytes;
+};
+
+struct xheader
+{
+  struct obstack *stk;
+  size_t size;
+  char *buffer;
+  uintmax_t string_length;
+};
+
+/* Information about xattrs for a file.  */
+struct xattr_array
   {
-    off_t offset;
-    size_t numbytes;
+    char *xkey;
+    char *xval_ptr;
+    size_t xval_len;
   };
 
 struct tar_stat_info
@@ -279,6 +296,15 @@ struct tar_stat_info
 
   char          *uname;     /* user name of owner */
   char          *gname;     /* group name of owner */
+
+  char *cntx_name;          /* SELinux context for the current archive entry. */
+
+  char *acls_a_ptr;         /* Access ACLs for the current archive entry. */
+  size_t acls_a_len;        /* Access ACLs for the current archive entry. */
+
+  char *acls_d_ptr;         /* Default ACLs for the current archive entry. */
+  size_t acls_d_len;        /* Default ACLs for the current archive entry. */
+
   struct stat   stat;       /* regular filesystem stat */
 
   /* STAT doesn't always have access, data modification, and status
@@ -293,17 +319,45 @@ struct tar_stat_info
   bool   is_sparse;         /* Is the file sparse */
 
   /* For sparse files: */
+  unsigned sparse_major;
+  unsigned sparse_minor;
   size_t sparse_map_avail;  /* Index to the first unused element in
                               sparse_map array. Zero if the file is
                               not sparse */
   size_t sparse_map_size;   /* Size of the sparse map */
   struct sp_array *sparse_map;
 
+  size_t xattr_map_size;   /* Size of the xattr map */
+  struct xattr_array *xattr_map;
+
+  /* Extended headers */
+  struct xheader xhdr;
+
   /* For dumpdirs */
   bool is_dumpdir;          /* Is the member a dumpdir? */
   bool skipped;             /* The member contents is already read
                               (for GNUTYPE_DUMPDIR) */
-  char *dumpdir;            /* Contents of the dump directory */    
+  char *dumpdir;            /* Contents of the dump directory */
+
+  /* Parent directory, if creating an archive.  This is null if the
+     file is at the top level.  */
+  struct tar_stat_info *parent;
+
+  /* Directory stream.  If this is not null, it is in control of FD,
+     and should be closed instead of FD.  */
+  DIR *dirstream;
+
+  /* File descriptor, if creating an archive, and if a directory or a
+     regular file or a contiguous file.
+
+     It is zero if no file descriptor is available, either because it
+     was never needed or because it was open and then closed to
+     conserve on file descriptors.  (Standard input is never used
+     here, so zero cannot be a valid file descriptor.)
+
+     It is negative if it could not be reopened after it was closed.
+     Negate it to find out what errno was when the reopen failed.  */
+  int fd;
 };
 
 union block
@@ -316,5 +370,3 @@ union block
   struct star_in_header star_in_header;
   struct star_ext_header star_ext_header;
 };
-
-/* End of Format description.  */
This page took 0.023147 seconds and 4 git commands to generate.